import mala
from mala import printout

run = "Al_933K_XX"
# Add data
snap_path = ...
ldos_path = ...
out_path = ...


def initial_setup():
    # Load the parameters from the hyperparameter optimization
    parameters = mala.Parameters()

    # Specify the data scaling.
    parameters.data.input_rescaling_type = "feature-wise-standard"
    parameters.data.output_rescaling_type = "normal"

    # LDOS parameters.
    parameters.targets.ldos_gridsize = 250
    parameters.targets.ldos_gridspacing_ev = 0.1
    parameters.targets.ldos_gridoffset_ev = -10
    parameters.network.layer_activations = ["LeakyReLU"]
    parameters.descriptors.descriptor_type = "Bispectrum"
    parameters.descriptors.use_atomic_density_energy_formula = False
    parameters.descriptors.bispectrum_twojmax = 10
    parameters.descriptors.bispectrum_cutoff = 4.67637
    parameters.descriptors.bispectrum_switchflag = 0


    # Specify the training parameters, these are not completely the same as
    # for the hyperparameter optimization.
    parameters.running.early_stopping_epochs = 8
    parameters.running.early_stopping_threshold = 0
    parameters.running.learning_rate = 0.00005
    parameters.running.trainingtype = "Adam"
    parameters.running.learning_rate_scheduler = "ReduceLROnPlateau"
    parameters.running.learning_rate_decay = 0.1
    parameters.running.learning_rate_patience = 4
    parameters.verbosity = 1
    parameters.running.max_number_epochs = 10000
    parameters.running.mini_batch_size = 1000
    parameters.use_gpu = True
    parameters.running.use_graphs = True
    parameters.data.use_lazy_loading = True
    parameters.running.checkpoints_each_epoch = 5
    parameters.running.checkpoint_name = run+"_chkpnt"

    # Add data to the run.
    data_handler = mala.DataHandler(parameters)

    # Add data according to model you want to train
    for i in range(0, ...):
        data_handler.add_snapshot("Al_snapshot"+str(i)+".in.npy", snap_path,
                                  "Al_snapshot"+str(i)+".out.npy", ldos_path,
                                  add_snapshot_as="tr",
                                  output_units="1/(Ry*Bohr^3)")
    for i in range(..., ...):
        data_handler.add_snapshot("Al_snapshot"+str(i)+".in.npy", snap_path,
                                  "Al_snapshot"+str(i)+".out.npy", ldos_path,
                                  add_snapshot_as="va",
                                  output_units="1/(Ry*Bohr^3)")
    data_handler.prepare_data()

    # Build and train network.
    parameters.network.layer_sizes = [data_handler.input_dimension, 4000,
                                      4000, 4000, 250,
                                      data_handler.output_dimension]
    network = mala.Network(parameters)
    trainer = mala.Trainer(parameters, network, data_handler)

    return parameters, network, data_handler, trainer


if mala.Trainer.run_exists(run+"_chkpnt"):
    parameters, network, data_handler, trainer = mala.Trainer.load_run(run+"_chkpnt")
else:
    parameters, network, data_handler, trainer = initial_setup()

trainer.train_network()
trainer.save_run(run,
                 additional_calculation_data=out_path +"Al_snapshot0.out")
